/*
 * heal.sp
 * Copyright (c) 2021 Ed <https://d-rine.com/~ed/>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#include <sourcemod>

#define HEAL_SOUNDFX "items/smallmedkit1.wav"

Handle hcvLimit;
int healLimit[32+1];

public Plugin:myinfo =
{
	name = "Player Self Heal",
	author = "EDSHOT",
	version = "0.1"
};

public void OnPluginStart()
{
	hcvLimit = CreateConVar("sm_heallimit", "4");
	RegConsoleCmd("sm_heal", heal);
	PrecacheSound(HEAL_SOUNDFX, true);
	HookEvent("player_death", Event_PlayerDeath);
	LoadTranslations("edshot_heal.phrases");
}

public void OnPluginEnd()
{
	UnhookEvent("player_death", Event_PlayerDeath);
}

public OnMapStart()
{
	PrecacheSound(HEAL_SOUNDFX, true);
	for (int p; p <= GetMaxClients(); p++) healLimit[p] = 0;
}

public Action heal(int client, int args)
{
	if (!IsClientConnected(client) || !IsClientInGame(client) || IsFakeClient(client) || !IsPlayerAlive(client))
	{
		return Plugin_Handled;
	}

	int hp = GetClientHealth(client);
	if (hp >= 100)
	{
		PrintToChat(client, "[SM] %T", "MESSAGE2", client);
		return Plugin_Handled;
	}

	if ((healLimit[client] >= 0) && (healLimit[client] < GetConVarInt(hcvLimit)))
	{
		int hpaddition = GetConVarInt(FindConVar("sk_healthkit"));
		SetEntityHealth(client, (hp + hpaddition));
		ClientCommand(client, "play \"%s\"", HEAL_SOUNDFX);
		healLimit[client]++;
	}

	PrintToChat(client, "[SM] %T", "MESSAGE", client, (GetConVarInt(hcvLimit) - healLimit[client]));
	return Plugin_Handled;
}

public void Event_PlayerDeath(Event event, const char[] name, bool dontBroadcast)
{
	int pid = GetClientOfUserId(event.GetInt("userid"));
	healLimit[pid] = 0;
}
